/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Maven2Utils.java 3878 2008-09-18 07:30:21Z fornacif $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.plan.fetcher.impl.maven2;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;

/**
 * Maven2 Utilities.
 * @author Francois Fornaciari
 */
public final class Maven2Utils {

    /**
     * Private empty constructor.
     */
    private Maven2Utils() {
    }

    /**
     * @param repository Repository path
     * @param groupId Artifact groupId
     * @param artifactId Artifact ID
     * @param version Artifact version
     * @param classifier Artifact's classifier (may be null)
     * @param type Artifact type
     * @return The resource location
     */
    public static String getMaven2Location(final String repository, final String groupId, final String artifactId,
            final String version, final String classifier, final String type) {

        // Creates a File from artifact info
        String appendedClassifier = "";
        if (classifier != null) {
            // Handle classifier if any
            appendedClassifier = appendedClassifier.concat("-").concat(classifier);
        }
        String path = constructDirectoryPath(groupId, artifactId, version);
        String location = repository.concat("/").concat(
                path.concat("/").concat(artifactId).concat("-").concat(version).concat(appendedClassifier).concat(".").concat(
                        type));
        return location;
    }

    /**
     * @param repository Repository path
     * @param groupId Artifact groupId
     * @param artifactId Artifact ID
     * @param version Artifact version
     * @param classifier Artifact's classifier (may be null)
     * @param type Artifact type
     * @return The resource file
     */
    public static File getMaven2File(final String repository, final String groupId, final String artifactId,
            final String version, final String classifier, final String type) {
        return new File(getMaven2Location(repository, groupId, artifactId, version, classifier, type));
    }

    /**
     * @param repository Repository path
     * @param groupId Artifact groupId
     * @param artifactId Artifact ID
     * @param version Artifact version
     * @param classifier Artifact's classifier (may be null)
     * @param type Artifact type
     * @return The resource URL
     * @throws MalformedURLException
     */
    public static URL getMaven2URL(final String repository, final String groupId, final String artifactId,
            final String version, final String classifier, final String type) throws MalformedURLException {
        return new URL(getMaven2Location(repository, groupId, artifactId, version, classifier, type));
    }

    /**
     * @param groupId Artifact groupId
     * @param artifactId Artifact ID
     * @param version Artifact version
     * @return transform the artifact coordinates into a m2 repository path
     */
    private static String constructDirectoryPath(final String groupId, final String artifactId, final String version) {
        // Transform groupId '.' into '/'
        String transformed = groupId.replace('.', '/');
        return transformed.concat("/").concat(artifactId).concat("/").concat(version);
    }
}
